"use client";

import { Checkbox } from "@/components/ui/checkbox";
import {
  Command,
  CommandGroup,
  CommandItem,
  CommandList,
  CommandSeparator,
} from "@/components/ui/command";
import { cn } from "@/lib/utils";
import {
  DropdownMenu,
  DropdownMenuTrigger,
  DropdownMenuContent,
  DropdownMenuItem,
} from "@/components/ui/dropdown-menu";
import { Check, Edit, MoreHorizontal, Plus, Trash2 } from "lucide-react";
import React, { useState } from "react";
import { Button } from "@/components/ui/button";
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover";
import { TagAdd } from "./tag-add";
import {
  AlertDialogHeader,
  AlertDialogFooter,
  AlertDialog,
  AlertDialogContent,
  AlertDialogTitle,
  AlertDialogDescription,
  AlertDialogAction,
  AlertDialogCancel,
} from "@/components/ui/alert-dialog";
import { Dialog, DialogContent } from "@/components/ui/dialog";
import { ScrollArea } from "@/components/ui/scroll-area";

interface ITagList2OptionsProps {
  tag: TagItem;
}

const TagList2Options = ({ tag }: ITagList2OptionsProps) => {
  const [openDeleteDialog, setOpenDeleteDialog] = useState(false);
  const [openEditDialog, setOpenEditDialog] = useState(false);
  const handleDelete = () => setOpenDeleteDialog(false);

  return (
    <>
      <DropdownMenu>
        <DropdownMenuTrigger asChild>
          <Button variant="ghost" className="w-fit h-fit p-0">
            <MoreHorizontal className="w-4 h-4" strokeWidth={1.5} />
          </Button>
        </DropdownMenuTrigger>
        <DropdownMenuContent>
          <Popover open={true}>
            <PopoverTrigger asChild>
              <DropdownMenuItem
                className="cursor-pointer"
                // onClick={() => setOpenEditDialog(true)}
              >
                <Edit className="w-4 h-4 mr-2" />
                <span>编辑</span>
              </DropdownMenuItem>
            </PopoverTrigger>
            <PopoverContent className="h-fit w-fit">
              <TagAdd color={tag.color} value={tag.name} />
            </PopoverContent>
          </Popover>
          <DropdownMenuItem
            className={cn("cursor-pointer text-red-600 focus:text-red-600")}
            onClick={() => setOpenDeleteDialog(true)}
          >
            <Trash2 className="w-4 h-4 mr-2" />
            <span>删除</span>
          </DropdownMenuItem>
        </DropdownMenuContent>
      </DropdownMenu>
      {/* edit */}

      {/* <Dialog open={openEditDialog} onOpenChange={setOpenEditDialog}>
        <DialogContent className="">
          <TagAdd color={tag.color} value={tag.name} />
        </DialogContent>
      </Dialog> */}
      {/* delete */}
      <AlertDialog open={openDeleteDialog} onOpenChange={setOpenDeleteDialog}>
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>删除标签</AlertDialogTitle>
            <AlertDialogDescription>
              确认删除标签{`"${tag.name}"`}吗?
            </AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel>取消</AlertDialogCancel>
            <AlertDialogAction
              className=" bg-red-600 text-white hover:bg-red-400"
              // onClick={handleDelete}
            >
              确认删除
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
    </>
  );
};

interface ITagListProps extends React.HTMLAttributes<HTMLDivElement> {
  list: TagItem[];
}

export default function TagList2({ list, className }: ITagListProps) {
  const [selectedTags, setSelectedTags] = useState<string[]>([]);
  const handleSelect = (id: string) => {
    if (selectedTags.includes(id)) {
      setSelectedTags(selectedTags.filter((it) => it !== id));
    } else {
      setSelectedTags([...selectedTags, id]);
    }
  };

  const [openTagAdd, setOpenTagAdd] = useState(false);
  return (
    <Command className={cn("rounded-lg border shadow-md h-fit p-2", className)}>
      <CommandList>
        <CommandGroup>
          <CommandItem className="flex justify-between items-center cursor-pointer">
            <span>显示全部</span>
            {!(selectedTags.length > 0) && (
              <Check className="ml-2 h-4 w-4 text-primary" />
            )}
          </CommandItem>
        </CommandGroup>
        <CommandSeparator />
        <CommandGroup>
          <ScrollArea className=" max-h-32">
            {list.map((tag) => (
              <CommandItem
                value={tag.id + ""}
                key={tag.id}
                className="flex justify-between items-center cursor-pointer"
              >
                <div className="flex justify-start items-center gap-2">
                  <Checkbox
                    checked={selectedTags.includes(tag.id + "")}
                    onClick={() => handleSelect(tag.id + "")}
                  />
                  <div className={cn("h-2 w-2 rounded-[2px]", tag.color)} />
                  <span>{tag.name}</span>
                </div>
                <TagList2Options tag={tag} />
              </CommandItem>
            ))}
          </ScrollArea>
        </CommandGroup>
        <CommandSeparator />
        <CommandGroup>
          <CommandItem className="cursor-pointer">
            <Popover open={openTagAdd} onOpenChange={setOpenTagAdd}>
              <PopoverTrigger asChild>
                <div className="flex w-full" aria-expanded={openTagAdd}>
                  <Plus className="w-4 h-4 mr-2" />
                  <span>新建标签</span>
                </div>
              </PopoverTrigger>
              <PopoverContent className="w-[200px] p-0">
                <TagAdd />
              </PopoverContent>
            </Popover>
          </CommandItem>
        </CommandGroup>
      </CommandList>
    </Command>
  );
}
